@@ -4,7 +4,7 @@ import os
 import mkdpdf
 
 # FILE SYSTEM
-DIRECTORY_PATH_OUTPUT = os.environ["DIRECTORY_PATH"] if "DIRECTORY_PATH" in os.environ else os.getcwd()
+DIRECTORY_PATH_OUTPUT = os.environ["DIRECTORY_PATH_OUTPUT"] if "DIRECTORY_PATH_OUTPUT" in os.environ else os.getcwd()
 DIRECTORY_PATH_PACKAGE = os.path.dirname(mkdpdf.__file__)
 FILENAME = (os.environ["FILENAME"].split(".")[0] if "." in os.environ["FILENAME"] else os.environ["FILENAME"]) if "FILENAME" in os.environ else None
 
