@@ -1,27 +1,34 @@
+import inspect
 import os
 import re
+import smtplib
+
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
 
 from mkdpdf import configuration
 from mkdpdf.md.md import MD
 from mkdpdf.pdf.pdf import PDF
-import inspect
+
 class Document:
     """
     Document is a Markdown or Portable Document Format document.
     """
 
-    def __init__(self, format: str = configuration.FORMAT, filename: str = configuration.FILENAME, directory_path_output: str = configuration.DIRECTORY_PATH_OUTPUT, directory_name_templates: str = None):
+    def __init__(self, title: str = None, format: str = configuration.FORMAT, filename: str = configuration.FILENAME, directory_path_output: str = configuration.DIRECTORY_PATH_OUTPUT, directory_name_templates: str = None, directory_path_templates: str = None, email_host: str = None):
         """
         Args:
             directory_path_output (string): path of output directory
+            directory_path_templates (string): path of template directory
             directory_name_templates (string): directory name of sub directory inside base templates directory
+            email_host (string): email domain from which to send
             filename (string): name of output file
             format (enum): md || pdf
         """
 
         # determine where submodule is
-        stack_callers = [d[1] for d in inspect.stack() if d[1].startswith("/tmp/ipykernel_")]
-
+        # package or console script
+        stack_callers = [d[1] for d in inspect.stack() if d[1].startswith("/tmp/ipykernel_") or not d[1].endswith(".py")]
         run_from_stack = len(stack_callers) > 0
 
         # if running from stack
@@ -31,17 +38,17 @@ class Document:
             index_of_stack_kernel = [d[1] for d in inspect.stack()].index(stack_kernel_file)
             file_path_stack = inspect.stack()[index_of_stack_kernel - 1][1]
             directory_path_stack_caller = "/".join(file_path_stack.split("/")[0:-1])
-
             # determine where core templates are
             file_path_stack = inspect.stack()[index_of_stack_kernel - 2][1]
             directory_path_stack_core = "/".join(file_path_stack.split("/")[0:-1])
 
         # update self
+        self.email_host = email_host
         self.format = format.lower()
         self.directory_path_output = directory_path_output
 
         # get base template directory
-        directory_path_templates = os.path.join(directory_path_stack_caller, "templates", self.format) if run_from_stack else os.path.join(configuration.DIRECTORY_PATH_PACKAGE, self.__class__.__name__.lower(), "templates", self.format)
+        directory_path_templates = directory_path_templates if directory_path_templates else  (os.path.join(directory_path_stack_caller, "templates", self.format) if run_from_stack else os.path.join(configuration.DIRECTORY_PATH_PACKAGE, self.__class__.__name__.lower(), "templates", self.format))
         self.directory_path_templates = os.path.join(directory_path_templates, directory_name_templates) if directory_name_templates else directory_path_templates
         self.directory_path_templates_core = os.path.join(directory_path_stack_core, "templates", self.format) if run_from_stack else directory_path_templates
 
@@ -58,6 +65,7 @@ class Document:
             self.format
         )
         self.file_path = os.path.join(self.directory_path_output, self.filename)
+        self.title = title if title else self.filename.split(".%s" % self.format)[0]
 
     def assemble(self, main: str = None, header: str = None, footer:str = None) -> tuple:
         """
@@ -105,6 +113,43 @@ class Document:
 
         return self.document.construct(header, main, footer)
 
+    def email(self, text: str, sender: str, recipients: list, html: str = None, host: str = None, subject: str = None):
+        """
+        Email a document in text and html formats via SMTP.
+
+        Args:
+            host (string): email domain from which to send
+            html (string): html content
+            recipients (list): email addresses
+            sender (string): email address
+            subject (string): email subject text
+            text (string): text content
+        """
+
+        HOST = host if host else self.email_host
+        TO = [recipients] if isinstance(recipients, str) else recipients
+
+        # initialize message
+        msg = MIMEMultipart("alternative")
+        msg["Subject"] = subject if subject else self.title
+        msg["From"] = sender
+        msg["To"] = ";".join(TO)
+
+        # assemble content
+        part1 = MIMEText(text, "plain")
+        part2 = MIMEText(html if html else "<div>%s</div>" % text, "html")
+
+        # attach content to message
+        msg.attach(part1)
+        msg.attach(part2)
+
+        # send message
+        server = smtplib.SMTP(HOST, port=587)
+        server.starttls()
+        server.login(sender, os.environ["EMAIL_PASSWORD"])
+        server.sendmail(sender, TO, msg.as_string())
+        server.quit()
+
     def generate(self, main = None, header = None, footer = None, to_file: bool = False):
         """
         Generate document.
@@ -139,7 +184,7 @@ class Document:
         Render document to filesystem.
 
         Args:
-            content ()
+            content (string): partial of Markdown or HTML
             file_path (string): output file path
         """
 
